@@ -4,7 +4,7 @@ from .base import base
 
 class user(base):
 
-    def __init__(self, token, app_secret):
+    def __init__(self, token, app_secret=None):
         super().__init__(token, app_secret)
 
     def get(self):
